#
# spec file for package librubberband
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define library_name librubberband2
Name:           librubberband
Version:        1.8.1
Release:        5.3
Summary:        Audio time-stretching and pitch-shifting library
License:        GPL-2.0+
Group:          System/Libraries
Url:            http://www.breakfastquay.com/rubberband/
Source:         http://code.breakfastquay.com/attachments/download/34/rubberband-%{version}.tar.bz2
Source1:        baselibs.conf
Patch1:         rubberband-mk.patch
BuildRequires:  dos2unix
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
BuildRequires:  help2man
BuildRequires:  ladspa-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libsndfile-devel
BuildRequires:  pkg-config
BuildRequires:  vamp-plugin-sdk-devel
Requires:       ladspa
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Rubber Band is a library and utility program that permits you to change the
tempo and pitch of an audio recording independently of one another.

%package -n     %{library_name}
Summary:        Audio time-stretching and pitch-shifting library
Group:          System/Libraries
Url:            http://www.breakfastquay.com/rubberband/

%description -n %{library_name}
Rubber Band is a library and utility program that permits you to change the
tempo and pitch of an audio recording independently of one another.

%package -n     rubberband-cli
Summary:        Command line interface for %{name}
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Requires:       %{library_name} = %{version}

%description -n rubberband-cli
Package rubberband-cli contains a command-line utility that can be used to exploit
Rubber Band's capabilities.

%package -n     rubberband-ladspa
Summary:        LADSPA plugin for %{name}
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Requires:       %{library_name} = %{version}

%description -n rubberband-ladspa
Package rubberband-ladspa is LADSPA plugin that can change the pitch of a sound in real-time.

%package -n     rubberband-vamp
Summary:        Vamp plugins for %{name}
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Requires:       %{library_name} = %{version}

%description -n rubberband-vamp
This package contains the following Vamp plugins:
 * increments (Output Increments): Output time increment for each
   input step
 * aggregate_increments (Accumulated Output Increments): Accumulated
   output time increments
 * divergence (Divergence from Linear): Difference between actual
   output time and the output time for a theoretical linear stretch
 * phaseresetdf (Phase Reset Detection Function): Curve whose peaks
   are used to identify transients for phase reset points
 * smoothedphaseresetdf (Smoothed Phase Reset Detection Function):
   Phase reset curve smoothed for peak picking
 * phaseresetpoints (Phase Reset Points): Points estimated as
   transients at which phase reset occurs
 * timesyncpoints (Time Sync Points): Salient points which stretcher
   aims to place with strictly correct timing

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{library_name} = %{version}
Requires:       pkgconfig

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q -n rubberband-%{version}
%patch1
# Fix README EOL encoding
dos2unix -o README.txt
mv README.txt README

%build
%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
rm %{buildroot}%{_libdir}/*.a

%if 0%{?suse_version} > 1140
mkdir -p %{buildroot}%{_mandir}/man1
pushd %{buildroot}%{_mandir}/man1
cp -v %{buildroot}%{_bindir}/rubberband ./
help2man --no-discard-stderr \
	-N -o rubberband.1 ./rubberband
rm rubberband
popd
%endif

%post -n %{library_name} -p /sbin/ldconfig

%postun -n %{library_name} -p /sbin/ldconfig

%files -n %{library_name}
%defattr(-,root,root,-)
%doc README COPYING
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%doc
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/rubberband.pc

%files -n rubberband-cli
%defattr(-,root,root,-)
%{_bindir}/rubberband
%if 0%{?suse_version} > 1140
%{_mandir}/man1/rubberband.1.gz
%endif

%files -n rubberband-ladspa
%defattr(-,root,root,-)
%dir %{_libdir}/ladspa
%dir %{_datadir}/ladspa
%dir %{_datadir}/ladspa/rdf
%{_libdir}/ladspa/ladspa-rubberband.*
%{_datadir}/ladspa/rdf/ladspa-rubberband.rdf

%files -n rubberband-vamp
%defattr(-,root,root,-)
%dir %{_libdir}/vamp
%{_libdir}/vamp/vamp-rubberband.*

%changelog
* Thu Jul 16 2015 olaf@aepfle.de
- Fix build in SLE_11 by disabling usage of help2man
* Mon Feb 16 2015 tchvatal@suse.com
- Cleanup with spec-cleaner
- Remove conditional for < 11.4
- Add baselibs.conf to spec as source
* Thu Feb 12 2015 p.drouand@gmail.com
- Update to version 1.8.1
  * Fix a crash in formant-preserving pitch shift for some build targets
- Remove COPYING file from sources; upstreamed
- Remove fix-cstdio.patch; fixed on upstream release
- Use download Url as source
* Sun May 22 2011 davejplater@gmail.com
- Fix README eol encoding with dos2unix.
- Added rubberband help2man man page generator to spec.
- Downloaded GPLv2 license to replace incorrect COPYING.
* Thu May 19 2011 mseben@gmail.com
- updated to 1.6
  * Add Smoothing option.  This uses a window-presum FFT, introducing
  time-domain aliasing which is then smoothed using a sinc window.
  This can be used in combination with any of the existing processing
  control options.  This will soften transients but the result may
  still be more pleasant for some material that is not very amenable
  to being time stretched.
  * Fix silent channel of output when processing with band-limited
  transients option
  * Include libresample support
- added fix-cstdio.patch to fix build
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
* Wed Oct 20 2010 mseben@gmail.com
- updated to 1.5
  * Add a more reliable transient detection mode, and make the mode
  selectable using OptionDetectorXXX flags -- the new method is
  the default
  * Band-limit transient detectors to avoid being distracted by
  inaudible garbage
  * Add a key-frame mapping facility for variable stretch ratio
  management during offline stretches
- changes in Rubber Band v1.4
  * Fix a hang when faced with some very peculiar stretch factors
  * Fix some incorrect threading condition usage
  * Some code rearrangement
  * Fix build on Solaris
- dopped rubberband-gcc44.patch
* Fri Jul 17 2009 mseben@suse.cz
- add missing COPYING file with GPLv2 (bnc#522202)
* Tue Jul  7 2009 mseben@suse.cz
- initial package for openSUSE
